@@ -7,8 +7,8 @@ CV.S=function (y, S, W = NULL, trim = 0, draw = FALSE, metric = metric.lp, ...)
         y2 = t(y$data)
         y.est = t(S %*% y2)
         y.est <- fdata(y.est, y$argvals, y$rangeval, y$names)
-        e <- (y - y.est)/(1-diag(S))
-#        e$data<-sqrt(W)%*%(e$data)     
+        #e <- (      y - y.est)/(1-diag(S))
+        e <- fdata(sweep((y - y.est)$data,2,1-diag(S),"%/%"), y$argvals, y$rangeval, y$names)
         ee <- drop(norm.fdata(e, metric = metric, ...)[, 1]^2)
         if (trim > 0) {
             e.trunc = quantile(ee, probs = (1 - trim), na.rm = TRUE, type = 4)
