@@ -4,7 +4,7 @@ DCP=out.influ$DCP
 DCE=out.influ$DCE
 DP=out.influ$DP
 fdataobj=model$fdataobj
-nas<-apply(fdataobj$data,1,count.na)
+nas<-is.na.fdata(fdataobj)
 if (any(nas))  {
    fdataobj$data<-fdataobj$data[!nas,]
    cat("Warning: ",sum(nas)," curves with NA are not used in the calculations \n")
