@@ -146,10 +146,10 @@ floor((ncol(DATA1) - nderiv - 4)/2), floor(ncol(DATA1)/3)),...)
  if (is.fdata(fdata1)) {
   tt<-fdata1[["argvals"]]
   rtt<-fdata1[["rangeval"]]
-  nas1<-apply(fdata1$data,1,count.na)
+  nas1<-is.na.fdata(fdata1)
   if (any(nas1))  stop("fdata1 contain ",sum(nas1)," curves with some NA value \n")
   else  if (!is.fdata(fdata2))  {fdata2<-fdata(fdata2,tt,rtt) }
-  nas2<-apply(fdata2$data,1,count.na)
+  nas2<-is.na.fdata(fdata2)
   if (any(nas2))  stop("fdata2 contain ",sum(nas2)," curves with some NA value \n")
   DATA1<-fdata1[["data"]]
   DATA2<-fdata2[["data"]]
@@ -246,10 +246,10 @@ floor((ncol(DATA1) - nderiv - 4)/2), floor(ncol(DATA1)/3)), period=NULL,...)
  if (is.fdata(fdata1)) {
   tt<-fdata1[["argvals"]]
   rtt<-fdata1[["rangeval"]]
-  nas1<-apply(fdata1$data,1,count.na)
+  nas1<-is.na.fdata(fdata1)
   if (any(nas1))  stop("fdata1 contain ",sum(nas1)," curves with some NA value \n")
   else  if (!is.fdata(fdata2))  {fdata2<-fdata(fdata2,tt,rtt) }
-  nas2<-apply(fdata2$data,1,count.na)
+  nas2<-is.na.fdata(fdata2)
   if (any(nas2))  stop("fdata2 contain ",sum(nas2)," curves with some NA value \n")
   DATA1<-fdata1[["data"]]
   DATA2<-fdata2[["data"]]
@@ -344,10 +344,10 @@ semimetric.hshift <- function(fdata1,fdata2=fdata1, t=1:ncol(DATA1),...)
  if (is.fdata(fdata1)) {
   tt<-fdata1[["argvals"]]
   rtt<-fdata1[["rangeval"]]
-  nas1<-apply(fdata1$data,1,count.na)
+  nas1<-is.na.fdata(fdata1)
   if (any(nas1))  stop("fdata1 contain ",sum(nas1)," curves with some NA value \n")
   else  if (!is.fdata(fdata2))  {fdata2<-fdata(fdata2,tt,rtt) }
-  nas2<-apply(fdata2$data,1,count.na)
+  nas2<-is.na.fdata(fdata2)
   if (any(nas2))  stop("fdata2 contain ",sum(nas2)," curves with some NA value \n")
   DATA1<-fdata1[["data"]]
   DATA2<-fdata2[["data"]]
@@ -404,10 +404,10 @@ semimetric.mplsr <- function(fdata1,fdata2=fdata1, q=2, class1,...)
  if (is.fdata(fdata1)) {
   tt<-fdata1[["argvals"]]
   rtt<-fdata1[["rangeval"]]
-  nas1<-apply(fdata1$data,1,count.na)
+  nas1<-is.na.fdata(fdata1)
   if (any(nas1))  stop("fdata1 contain ",sum(nas1)," curves with some NA value \n")
   else  if (!is.fdata(fdata2))  {fdata2<-fdata(fdata2,tt,rtt) }
-  nas2<-apply(fdata2$data,1,count.na)
+  nas2<-is.na.fdata(fdata2)
   if (any(nas2))  stop("fdata2 contain ",sum(nas2)," curves with some NA value \n")
   DATA1<-fdata1[["data"]]
   DATA2<-fdata2[["data"]]
@@ -479,10 +479,10 @@ semimetric.pca <- function(fdata1, fdata2=fdata1, q=1,...)
  if (is.fdata(fdata1)) {
   tt<-fdata1[["argvals"]]
   rtt<-fdata1[["rangeval"]]
-  nas1<-apply(fdata1$data,1,count.na)
+  nas1<-is.na.fdata(fdata1)
   if (any(nas1))  stop("fdata1 contain ",sum(nas1)," curves with some NA value \n")
   else  if (!is.fdata(fdata2))  {fdata2<-fdata(fdata2,tt,rtt) }
-  nas2<-apply(fdata2$data,1,count.na)
+  nas2<-is.na.fdata(fdata2)
   if (any(nas2))  stop("fdata2 contain ",sum(nas2)," curves with some NA value \n")
   DATA1<-fdata1[["data"]]
   DATA2<-fdata2[["data"]]
